@@ -44,7 +44,7 @@
         n <- length(x)
       }
       else{
-        ord <- (hist(i,plot=F,freq=T,breaks=seq(0.5,max(i)+0.5,1))$counts==1)
+        ord <- (hist(i,plot=FALSE,freq=TRUE,breaks=seq(0.5,max(i)+0.5,1))$counts==1)
         x <- x[ord]
         y <- y[ord]
         z <- z[ord]
